package Pcore::API::Backend::Local::Pg;

use Pcore -class;

with qw[Pcore::API::Backend::Local];

1;
__END__
=pod

=encoding utf8

=cut
